package com.ccwangluo.ccim.util;

import android.app.Activity;
import android.media.MediaPlayer;
import android.media.MediaRecorder;
import android.os.Build;
import android.os.Environment;

import java.io.File;
import java.io.IOException;

public class MediaHelper {
    private MediaRecorder mMediaRecorder;
    private String mFilePath;//文件

    private static MediaHelper mInstance;

    /**
     * 单例模式获取 MediaHelper
     * 双检锁/双重校验锁
     */
    public static MediaHelper getInstance() {
        if (mInstance == null) {
            synchronized (MediaHelper.class) {
                if (mInstance == null) {
                    mInstance = new MediaHelper();
                }
            }
        }
        return mInstance;
    }
    /**
     * 准备录音
     */
    public void prepare(Activity activity) {
        try {
            if (mMediaRecorder != null){
                cancel();
            }
            String path;
            if (Environment.getExternalStorageState().equals(Environment.MEDIA_MOUNTED)) {
               path = activity.getExternalFilesDir("test").getAbsolutePath();
            } else {
                path = activity.getCacheDir().getAbsolutePath();
            }
            File fileDir = new File(path);
            boolean b = !fileDir.exists();
            if (b) {
                fileDir.mkdirs();
            }
            String fileName = System.currentTimeMillis() + ".amr"; // 文件名字
            File file = new File(fileDir, fileName);  // 文件路径
            mMediaRecorder = new MediaRecorder();
            mFilePath = file.getAbsolutePath();
            //设置保存文件的路径
            if (Build.VERSION.SDK_INT < 26) {
                //若api低于26，调用setOutputFile(String path)
                mMediaRecorder.setOutputFile(file.getAbsolutePath());
            } else {
                //若API高于26 使用setOutputFile(File path)
                mMediaRecorder.setOutputFile(new File(file.getAbsolutePath()));
            }
            mMediaRecorder.setAudioSource(MediaRecorder.AudioSource.MIC);    // 设置MediaRecorder的音频源为麦克风
            mMediaRecorder.setOutputFormat(MediaRecorder.OutputFormat.AAC_ADTS);    // 设置音频的格式
            mMediaRecorder.setAudioEncoder(MediaRecorder.AudioEncoder.AAC);    // 设置音频的编码为AMR_NB
            mMediaRecorder.prepare();
            mMediaRecorder.start();
        } catch (IllegalStateException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }
    /**
     * 释放资源
     */
    public void release() {
        if (mMediaRecorder != null) {
            mMediaRecorder.stop();
            mMediaRecorder.release();
            mMediaRecorder = null;
        }
    }
    /**
     * 取消
     */
    public void cancel() {
        release();
        //删除相应的录音
        if (mFilePath != null) {
            File file = new File(mFilePath);
            if (file.exists()) {
                file.delete();
            }
            mFilePath = null;
        }
    }

    /**
     * 播放
     * @param filePath
     */
    public void play(String filePath)  {
        MediaPlayer mediaPlayer = new MediaPlayer();
        try {
            mediaPlayer.setDataSource(filePath);
            mediaPlayer.prepare();
            //播放
            mediaPlayer.start();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }


    //获取生成的文件路径
    public String getFilePath() {
        return mFilePath;
    }
}